// Display each item of the list of albumsPage
// Each Item is contained in a Rectangle. Inside the Rectangle there is a Row containing
// an Icon and a Column with 2 texts : the album name and the count of photo in the albumId
// The Icon is displayed with a mask to get the look and feed of N9 icons
// The Icon is retrieved by a request to get information of the first file of the album to
// to the server. The server returns details of the first file including the url of the
// picture file. A PHP request is then used to fill the icon.
// While the request is in progress, a progress icon is displayed with the N9 look and feel.
// The count of  files in the album is returned by an additional request to get the properties
// of the album
// If the user clicks on an item, the message is forwarded to the instance of idAlbumsDelegate
// in order to be managed by the delegate item of the albumsPage.
// Important: If the user scrolls in the list view, the item might be destroyed while request
// is pending on Internet. Before destroying the list item, the request is cancelled
// (Component.onDestruction)
//
// To improve:
// - Highlight item when clicked
// - reduce code for sizing objects

import QtQuick 1.1
import com.nokia.meego 1.0
import "Constants.js" as Constants
import "UIConstants.js" as UIConstants
import "HttpRequests.js" as HttpRequests

Rectangle {
    id: idAlbumsDelegate

    color: UIConstants.LIST_COLOR

    signal clicked;

    property string label
    property string session
    property string albumId
    property string folderId
    property alias imageUrl : idAlbumsDelegateImage.source
    property alias nbFiles :  textNbFiles.text

    // Each Item is a row containing an Icon and a column of 2 text lines

    height: UIConstants.ALBUMS_ITEMS_HEIGHT
    width: (screen.currentOrientation == Screen.Portrait) ? 480 : 854

    Item {
        id: idIcon
        height: UIConstants.ALBUMS_ITEMS_HEIGHT-2
        width: UIConstants.ALBUMS_ITEMS_HEIGHT-2

        anchors {
            leftMargin: 10
            left: parent.left
            verticalCenter: parent.verticalCenter
        }

        Image {
            id: idAlbumsDelegateImage
            anchors.fill:parent
            smooth : true
            BusyIndicator {
                id: idBusyIndicator
                platformStyle: BusyIndicatorStyle { size: "small" }
                running: false
                anchors.centerIn: parent
            }
            onStatusChanged:{
                if (status == Image.Ready) {
                    idBusyIndicator.running = false
                    idBusyIndicator.visible = false
                }
            }
        }
        Image {
            id: idCache
            anchors.fill:parent
            smooth: true
            source :"qrc:///icons/cache.png"
        }
    }

    Rectangle {
        id: idLabels
        color: parent.color
        anchors {
            leftMargin: 10
            left: idIcon.right
            topMargin: 1
            top: parent.top
            right: parent.right
            bottomMargin: 1
            bottom: parent.bottom
        }
        Column {
            Text {
                id: textAlbumName
                text: idAlbumsDelegate.label
                font.pixelSize: UIConstants.TITLE_FONTSIZE
                color: "white"
            }
            Text {
                id: textNbFiles
                font.pixelSize: UIConstants.SUBTITLE_FONTSIZE
                color: "white"
            }
        }
    }

    // When an album item is displayed, a request is send to the server
    // to get the number of files
    Component.onCompleted: {
        if(albumId != "") {
            if (imageUrl == "") {
                HttpRequests.joomeoGetFirstFile(session, albumId);
            }
        }
        else
        {
            idAlbumsDelegateImage.source = "qrc:///icons/folder.png"
        }
    }

    // Don't forget to cancel pending request if item is destroyed before
    // the answer is received from the server
    Component.onDestruction: {
        HttpRequests.dismissRequest();
    }

    MouseArea {
        id: idAlbumsDelegateMouseArea
        anchors.fill: parent
        onPressed: {
            idLabels.color = Qt.lighter(idLabels.color,1.2);
        }

        onReleased: {
            idLabels.color = Qt.darker(idLabels.color, 1.2);
        }

        onCanceled: {
            idLabels.color = Qt.darker(idLabels.color, 1.2);
        }

        onClicked:
            idAlbumsDelegate.clicked();
    }
}
