// Display each item of the list of ContactsPage
// Each Item is contained in a Rectangle. Inside the Rectangle there is a Row containing
// an Icon and a Column with 2 texts : the contact name and last visit date
// The Icon is a static image because there is no function in the api to get the picture
// of the contact
// If the user clicks on an item, the message is forwarded to the instance of idContactsDelegate
// in order to be managed by the delegate item of the albumsPage.
//
// To improve:
// - Highlight item when clicked
// - reduce code for sizing objects

import QtQuick 1.1
import com.nokia.meego 1.0
import "Constants.js" as Constants
import "UIConstants.js" as UIConstants
import "HttpRequests.js" as HttpRequests

Rectangle {
    id: idContactsDelegate

    color: UIConstants.LIST_COLOR

    signal clicked;

    property string contactId
    property string contactName
    property string lastVisit

    // Each Item is a row containing an Icon and a column of 2 text lines

    Row {
        height: UIConstants.ALBUMS_ITEMS_HEIGHT -2
        width: (screen.currentOrientation == Screen.Portrait) ? 480 : 854
        spacing: 10

        Item {
            width: UIConstants.ALBUMS_ITEMS_HEIGHT - 2 + 10
            height: UIConstants.ALBUMS_ITEMS_HEIGHT - 2
            Image {
                width: UIConstants.ALBUMS_ITEMS_HEIGHT - 2
                height: UIConstants.ALBUMS_ITEMS_HEIGHT - 2
                anchors.centerIn: parent
                smooth: true
                source :"qrc:///icons/contact.png"
            }
        }
        Column {
            height: UIConstants.ALBUMS_ITEMS_HEIGHT - 2
            Text {
                id: textContactName
                text: idContactsDelegate.contactName
                font.pixelSize: UIConstants.TITLE_FONTSIZE
                color: "white"
                maximumLineCount: 1
                elide: Text.ElideRight
            }
            Text {
                id: textLastVisit
                font.pixelSize: UIConstants.SUBTITLE_FONTSIZE
                color: "white"
                text: Qt.formatDateTime(new Date(parseFloat(idContactsDelegate.lastVisit)), "dd MMM yyyy hh:mm:ss")
            }
        }
    }

    MouseArea {
        id: idContactsDelegateMouseArea
        anchors.fill: parent
        onClicked:
            idContactsDelegate.clicked();
    }
}
