// Page which displays the list of other accessible Joomeo accounts

import QtQuick 1.1
import com.nokia.meego 1.0
import "Constants.js" as Constants
import "UIConstants.js" as UIConstants
import "HttpRequests.js" as HttpRequests


Page {
    id: contactsPage

    property bool testMode: false
    property string xmlData
    property bool pageBusy: true
    property string sessionId

    // Object to map Xml Response from a getNetworkRequest into listview items
    // Only three fields per item are kept to display the list view:
    // Id and Name of the contact and date/time of the last connection

    XmlListModel {
        id: xmlContactsModel
        xml: xmlData
        query: "/methodResponse/params/param/value/array/data/value/struct"

        XmlRole { name: "contactId"; query: "member[name='contactid']/value/string/string()" }
        XmlRole { name: "contactName"; query: "member[name='username']/value/string/string()" }
        XmlRole { name: "lastVisit"; query: "member[name='lastvisit']/value/double/string()" }
    }

    // Page is made with a header: Rectangle at the top of the screen.
    // Top borders are rounded because display is clipped by the page
    // Two Labels are placed in the Rectangle for the page title (Network) and
    // the count of contacts

    Rectangle {
        id: idContactsHeader
        width: (screen.currentOrientation == Screen.Portrait) ? 480 : 854
        height: UIConstants.HEADER_HEIGHT

        anchors {
            top: parent.top
        }

        Rectangle {
            color: UIConstants.HEADER_COLOR
            anchors.fill: parent

            Text {
                id: idTextContactsHeader
                text: qsTr("Network")
                font.pixelSize: UIConstants.TITLE_FONTSIZE
                anchors {
                    verticalCenter: parent.verticalCenter
                    left:parent.left
                    leftMargin: 10
                }
                color: UIConstants.HEADER_TEXT_COLOR
            }
            Text {
                id: idTextNbContacts
                text: (listView.count >= 0 ? listView.count + " "+qsTr("Contacts") : "")
                font.pixelSize: UIConstants.TITLE_FONTSIZE
                anchors {
                    verticalCenter: parent.verticalCenter
                    right: parent.right
                    rightMargin: 10
                }
                color: UIConstants.HEADER_TEXT_COLOR
            }
            // Separator
            Rectangle {
                width: parent.width
                height: 1
                anchors.bottom: parent.bottom
                color: UIConstants.SEPARATOR_COLOR
            }
        }
    }


    ListView {
        id: listView
        model: xmlContactsModel
        clip: true
        focus: true

        anchors {
            top: idContactsHeader.bottom
            left: parent.left
            right: parent.right
            bottom: parent.bottom
        }

        delegate: ContactsDelegate {
            width: (screen.currentOrientation == Screen.Portrait) ? 480 : 854
            height: UIConstants.ALBUMS_ITEMS_HEIGHT

            // Link Xml data format to listview element properties
            contactId: model.contactId
            contactName : model.contactName
            lastVisit: model.lastVisit

            // What to do when a name is clicked
            onClicked: {
                appWindow.pageStack.push(Qt.resolvedUrl("AlbumsPage.qml"),
                                         { sessionId: sessionId,
                                           contactId: contactId});
            }
        }
    } // ListView

    ScrollDecorator {
        flickableItem: listView
    }

    // When the page is shown, a network request is sent to get
    // the list of contacts

    onStatusChanged: {
        if (status == PageStatus.Active) {
            HttpRequests.joomeoGetNetwork(sessionId);
            timer.start();
        }
    }

    // Network error dialog
    ErrorDialog {
        id: networkErrorDialog
        message : qsTr("Network problem\n(Loss of connection ?)")+" "
    } // Dialog


    // Login error dialog
    ErrorDialog {
        id: loginErrorDialog
        message : qsTr("Connection rejected\n(Spacename, Username, password incorrect?)")+" "
    } // Dialog

    // Network timeout timer
    Timer {
        id: timer
        interval: Constants.NETWORK_TIMEOUT
        repeat: false
        onTriggered: HttpRequests.req.abort();
    }

    tools: ToolBarLayout {
        ToolIcon {
            iconId: "toolbar-back"
            onClicked: {
                appWindow.pageStack.pop()
            }
        }
        /*
        ToolIcon {
            enabled: false
            width: 180
            Image {
                source: "qrc:///icons/joomeo2.png"
                anchors.centerIn: parent
            }
        }
        */
    }
}
