/*
 * The javascript part of the program
 * This file contains functions to get data from Joomeo Internet site,
 * parse a XML string containing XML-RPC response.
 * Depending on the message, the parsing is performed here or in QML code
 *
 * to improve:
 * - management of errors
 */


// The API key for Joomeo Online API
var API_KEY = "f1ce1b457664c0be59a70ec99b529f04"

// Url of joomeo access point for XML interface
var JOOMEO_XMLRPC_POINT = "http://api.joomeo.com/xmlrpc.php"

// Url of Joomeo access point for PHP interface
var JOOMEO_PHP_POINT = "http://api.joomeo.com/file.php"

// Timeout in milliseconds
var NETWORK_TIMEOUT = 10000;
var req;
var reqInProgress = new Boolean(false);
var apiKey = Constants.API_KEY;
var url = Constants.JOOMEO_XMLRPC_POINT;
var php = Constants.JOOMEO_PHP_POINT;


// Parse the <struct> section in XmlRpc

function parseStruct(node) {
    var res={};

    // Return a sub node from its name in Xml

    for(var j=0; j<node.childNodes.length; j++) {
        if(node.childNodes[j].nodeName == "member") {
            var i=0;

            var subnode = node.childNodes[j].childNodes;

            while(i < subnode.length) {
                if(subnode[i].nodeName == "name") {
                    var name = subnode[i].childNodes[0].data;
                    i++;

                    while(i < subnode.length) {
                        if(subnode[i].nodeName == "value") {
                            res[name]=parseValue(subnode[i]);
                        }
                        i++;
                    }
                }
                i++;
            }
        }
    }

    return res;
}


function parseMember(node) {
    var i=0;

    node = node.childNodes;

    while(i < node.length) {
        if(node[i].nodeName == "name") {
            var name = node[i].childNodes[0].data;
            i++;

            while(i < node.length) {
                if(node[i].nodeName == "value") {
                    var res={};
                    res[name]=parseValue(node[i]);
                    return res;
                }
                i++;
            }
        }
        i++;
    }
    throw "Parse Error";
}


// Return a sub node from its name in Xml
function getChildNode(node, nodeName) {

    for(var i=0; i<node.childNodes.length; i++)
        if(node.childNodes[i].nodeName == nodeName)
            return node.childNodes[i];

    throw "Node <"+nodeName+"> not found";
}

// Parse a <value> node
function parseValue(value) {

    var type = value.childNodes[0];

    if (type == null)
        return "";

    switch (type.nodeName) {
    case "boolean":
        return type.childNodes[0].data == "1" ? true : false;
    case "i4":
    case "int":
        return parseInt(type.childNodes[0].data);
    case "double":
        return parseFloat(type.childNodes[0].data);
    case "#text":
        return type.data;
    case "string":
        return type.childNodes[0].data;
    case "array":
        var data = type.childNodes[0];
        var res = new Array(data.childNodes.length);;
        for (var i=0; i < data.childNodes.length; i++)
            res[i] = parseValue(data.childNodes[i]);
        return res;
    case "struct":
        return parseStruct (type);

    case "dateTime.iso8601":
        var s = type.childNodes[0].data;
        var d = new Date();
        d.setUTCFullYear(s.substr(0, 4));
        d.setUTCMonth(parseInt(s.substr(4, 2)) - 1);
        d.setUTCDate(s.substr(6, 2));
        d.setUTCHours(s.substr(9, 2));
        d.setUTCMinutes(s.substr(12, 2));
        d.setUTCSeconds(s.substr(15, 2));
        return d;
    case "base64":
        alert("base64 not supported");
    default:
        throw "parser: expected type, got <"+type.nodeName+">";
    }
}

// Parse an XmlRpc response
function parseResponse(dom) {
    var node;

    node = getChildNode(dom, "params");
    node = getChildNode(node, "param");
    node = getChildNode(node, "value");

    return parseValue(node);
}

// Initialize session with Joomeo. Get a sessionId then request the list of albums

function joomeoSessionInit(spacename, username, password)
{
    if (reqInProgress == false) {
        req = new XMLHttpRequest();

        req.onreadystatechange = function() {
                    if (req.readyState == XMLHttpRequest.DONE)
                    {
                        timer.stop();

                        if ((req.status == "200" ) && (req.responseXML != null))
                        {
                            pageBusy = false;
                            reqInProgress = false;

                            try {
                                var ret;

                                // Xml is parsed with javscript code to get session id
                                ret = parseResponse(req.responseXML.documentElement);

                                sessionId = ret['sessionid'];
                                sessionType = ret['sessionType'];

                                // Get list of Albums
                                // joomeoGetAlbumsList(sessionId);
                                joomeoGetFolderChildren(sessionId, "");

                            } catch (err) {
                                console.log ("error msg:"+err)
                                loginErrorDialog.open();
                            }
                        }
                        else {
                            if (reqInProgress) {
                                reqInProgress = false;
                                networkErrorDialog.open();
                            }
                        }
                    }
                }

        var apiKey = Constants.API_KEY;

        if (apiKey.length != 0)
        {

            var data = "<?xml version=\"1.0\"?>\n"+
                    "<methodCall><methodName>joomeo.session.init</methodName>"+
                    "<params><param><value><struct><member><name>apikey</name><value><string>"+apiKey+"</string></value></member>"+
                    "<member><name>spacename</name><value><string>"+spacename+"</string></value></member>"+
                    "<member><name>login</name><value><string>"+username+"</string></value></member>"+
                    "<member><name>password</name><value><string>"+password+"</string></value></member>"+
                    "</struct></value></param></params></methodCall>";
            req.open("POST", url);
            req.send(data);

            reqInProgress = true;
        }
        else {
            console.log("Key for Joomeo API missing!");
            networkErrorDialog.open();
        }
    }
}

function joomeoInitContact(sessionid, contactid)
{
    if (reqInProgress == false) {

        req = new XMLHttpRequest();

        req.onreadystatechange = function() {
                    if (req.readyState == XMLHttpRequest.DONE)
                    {
                        timer.stop();

                        if ((req.status == "200" ) && (req.responseXML != null))
                        {
                            pageBusy = false;
                            reqInProgress = false;

                            try {
                                var ret;

                                // Xml is parsed with javscript code to get session id
                                ret = parseResponse(req.responseXML.documentElement);

                                sessionId = ret['sessionid'];
                                spacename = ret['spacename'];
                                sessionType = ret['sessionType'];

                                // Get list of Albums
                                // joomeoGetAlbumsList(sessionId);
                                joomeoGetFolderChildren(sessionId, "");

                            } catch (err) {
                                console.log ("error in joomeoInitContact")
                                loginErrorDialog.open();
                            }
                        }
                        else {
                            if (reqInProgress) {
                                reqInProgress = false;
                                networkErrorDialog.open();
                            }
                        }
                    }
                }

        var apiKey = Constants.API_KEY;

        if (apiKey.length != 0)
        {

            var data = "<?xml version=\"1.0\"?>\n"+
                    "<methodCall><methodName>joomeo.session.initContact</methodName>"+
                    "<params><param><value><struct><member><name>apikey</name><value><string>"+apiKey+"</string></value></member>"+
                    "<member><name>sessionid</name><value><string>"+sessionid+"</string></value></member>"+
                    "<member><name>contactid</name><value><string>"+contactid+"</string></value></member>"+
                    "</struct></value></param></params></methodCall>";
            req.open("POST", url);
            req.send(data);

            reqInProgress = true;
        }
        else {
            console.log("Key for Joomeo API missing!");
            networkErrorDialog.open();
        }
    }
}

function joomeoGetAlbumsList(sessionid)
{
    if (reqInProgress == false) {

        req = new XMLHttpRequest();

        req.onreadystatechange = function() {
                    if (req.readyState == XMLHttpRequest.DONE)
                    {
                        if ((req.status == "200") && (req.responseXML != null))
                        {
                            pageBusy = false;

                            // Transfer the response to the QML object for processing
                            xmlData = req.responseText;

                        }
                        else {
                            console.log("Unexpected error");

                            if (reqInProgress) {
                                networkErrorDialog.open();
                            }
                        }

                        reqInProgress = false;
                        timer.stop();
                    }
                }

        if (apiKey.length != 0)
        {

            var data = "<?xml version=\"1.0\"?>\n"+
                    "<methodCall><methodName>joomeo.user.getAlbumList</methodName>"+
                    "￼<params><param><value><struct><member><name>apikey</name><value><string>"+
                    apiKey+"</string></value></member><member><name>sessionid</name><value><string>"+
                    sessionid+"</string></value></member><member><name>orderby</name><value><string>"+
                    "date</string></value></member></struct></value></param></params></methodCall>";
            req.open("POST", url);
            req.send(data);

            reqInProgress = true;
        }
        else {
            console.log("Key for Joomeo API missing!");
            networkErrorDialog.open();
        }
    }
}

function joomeoGetFolderChildren(sessionid, folderid)
{
    if (reqInProgress == false) {

        req = new XMLHttpRequest();

        req.onreadystatechange = function() {
                    if (req.readyState == XMLHttpRequest.DONE)
                    {
                        if ((req.status == "200") && (req.responseXML != null))
                        {
                            pageBusy = false;

                            // Transfer the response to the QML object for processing
                            xmlData = req.responseText;

                        }
                        else {
                            console.log("Unexpected error");

                            if (reqInProgress) {
                                networkErrorDialog.open();
                            }
                        }

                        reqInProgress = false;
                        timer.stop();
                    }
                }

        if (apiKey.length != 0)
        {

            console.log("getFolderChildren("+sessionid+","+folderid+")")

            var data = "<?xml version=\"1.0\"?>\n"+
                    "<methodCall><methodName>joomeo.user.getFolderChildren</methodName>"+
                    "￼<params><param><value><struct>"+
                    "<member><name>apikey</name><value><string>"+apiKey+"</string></value></member>"+
                    "<member><name>sessionid</name><value><string>"+sessionid+"</string></value></member>"+
                    "<member><name>folderid</name><value><string>"+folderid+"</string></value></member>"+
                    "<member><name>orderby</name><value><string>name</string></value></member>"+
                    "</struct></value></param></params></methodCall>";
            req.open("POST", url);
            req.send(data);

            reqInProgress = true;
        }
        else {
            console.log("Key for Joomeo API missing!");
            networkErrorDialog.open();
        }
    }
}


function joomeoGetFilesList(sessionid, albumid)
{
    if (reqInProgress == false) {
        req = new XMLHttpRequest();

        req.onreadystatechange = function() {
                    if (req.readyState == XMLHttpRequest.DONE)
                    {
                        if ((req.status == "200") && (req.responseXML != null))
                        {
                            xmlFilesData = req.responseText;
                            pageBusy = false;
                        }
                        else {
                            console.log("Unexpected error");

                            if (reqInProgress) {
                                networkErrorDialog.open();
                            }
                        }

                        reqInProgress = false;
                        timer.stop();
                    }
                }

        var apiKey = Constants.API_KEY;

        if (apiKey.length != 0)
        {

            var data = "<?xml version=\"1.0\" encoding=\"UTF-8\"?><methodCall>"+
                    "<methodName>joomeo.user.album.getFilesList</methodName><params><param><value><struct>"+
                    "<member><name>apikey</name><value><string>"+apiKey+"</string></value> </member>"+
                    "￼<member><name>sessionid</name> <value><string>"+sessionid+"</string></value></member>"+
                    "<member><name>albumid</name><value><string>"+albumid+"</string></value></member>"+
                    "<member><name>orderby</name><value><string>date</string></value></member>"+
                    "<member><name>random</name><value><int>0</int></value> </member>"+
                    "<member><name>maxresult</name><value><int>0</int></value></member></struct></value></param></params></methodCall>";
            req.open("POST", url);
            req.send(data);

            reqInProgress = true;
        }
        else {
            console.log("Key for Joomeo API missing!");
            networkErrorDialog.open();
        }
    }
}


function joomeoGetNetwork(sessionid)
{
    if (reqInProgress == false) {
        req = new XMLHttpRequest();

        req.onreadystatechange = function() {
                    if (req.readyState == XMLHttpRequest.DONE)
                    {
                        if ((req.status == "200") && (req.responseXML != null))
                        {
                            xmlData = req.responseText;
                            pageBusy = false;
                        }
                        else {
                            console.log("Unexpected error");

                            if (reqInProgress) {
                                networkErrorDialog.open();
                            }
                        }

                        reqInProgress = false;
                        timer.stop();
                    }
                }

        var apiKey = Constants.API_KEY;

        if (apiKey.length != 0)
        {

            var data = "<?xml version=\"1.0\" encoding=\"UTF-8\"?><methodCall>"+
                    "<methodName>joomeo.user.getNetwork</methodName><params><param><value><struct>"+
                    "<member><name>apikey</name><value><string>"+apiKey+"</string></value> </member>"+
                    "￼<member><name>sessionid</name> <value><string>"+sessionid+"</string></value></member>"+
                    "</struct></value></param></params></methodCall>";

            req.open("POST", url);
            req.send(data);

            reqInProgress = true;
        }
        else {
            console.log("Key for Joomeo API missing!");
            networkErrorDialog.open();
        }
    }
}


function joomeoGetFirstFile(sessionid, albumid)
{
    if (reqInProgress == false) {

        req = new XMLHttpRequest();

        req.onreadystatechange = function() {
                    if (req.readyState == XMLHttpRequest.DONE)
                    {
                        if ((req.status == "200" ) && (req.responseXML != null))
                        {
                            try {
                                var ret;
                                var node;

                                node = getChildNode(req.responseXML.documentElement, "params");
                                node = getChildNode(node, "param");
                                node = getChildNode(node, "value");
                                node = getChildNode(node, "array");
                                node = getChildNode(node, "data");
                                node = getChildNode(node, "value");

                                ret = parseValue(node);

                                // Fill source property of the image with address of image to download
                                // See AlbumsDelegate
                                imageUrl=  Constants.JOOMEO_PHP_POINT +"?apikey="+Constants.API_KEY+"&sessionid="+sessionid+"&albumid="+albumid+"&fileid="+ret['fileid']+"&type=small&rotation=0";

                                reqInProgress = false;
                                joomeoGetNumberOfFiles(sessionid, albumid);

                            } catch (err) {
                            }
                        }
                        reqInProgress = false;
                    }
                }


        if (apiKey.length != 0)
        {
            var data = "<?xml version=\"1.0\" encoding=\"UTF-8\"?><methodCall>"+
                    "<methodName>joomeo.user.album.getFilesList</methodName><params><param><value><struct>"+
                    "<member><name>apikey</name><value><string>"+apiKey+"</string></value> </member>"+
                    "￼<member><name>sessionid</name> <value><string>"+sessionid+"</string></value></member>"+
                    "<member><name>albumid</name><value><string>"+albumid+"</string></value></member>"+
                    "<member><name>orderby</name><value><string>date</string></value></member>"+
                    "<member><name>random</name><value><int>0</int></value> </member>"+
                    "<member><name>startresult</name><value><int>0</int></value></member>"+
                    "<member><name>maxresult</name><value><int>1</int></value></member></struct></value></param></params></methodCall>";
            req.open("POST", url);
            req.send(data);

            reqInProgress = true;
        }
    } else {
        console.log("joomeoGetFirstFile: Simultaneous Request. Rejected!");
    }
}


function joomeoGetNumberOfFiles(sessionid, albumid)
{
    if (reqInProgress == false) {

        req = new XMLHttpRequest();

        req.onreadystatechange = function() {
                    if (req.readyState == XMLHttpRequest.DONE)
                    {
                        if ((req.status == "200" ) && (req.responseXML != null))
                        {
                            try {
                                var ret;
                                var node;

                                node = getChildNode(req.responseXML.documentElement, "params");
                                node = getChildNode(node, "param");
                                node = getChildNode(node, "value");

                                ret = parseValue(node);
                                nbFiles =  ret['nbfiles'] + " Photos";

                            } catch (err) {
                                console.log("error:"+err)
                            }
                        }
                        reqInProgress = false;
                    }
                }


        if (apiKey.length != 0)
        {
            var data = "<?xml version=\"1.0\" encoding=\"UTF-8\"?><methodCall>"+
                    "<methodName>joomeo.user.album.getNumberOfFiles</methodName><params><param><value><struct>"+
                    "<member><name>apikey</name><value><string>"+apiKey+"</string></value> </member>"+
                    "￼<member><name>sessionid</name> <value><string>"+sessionid+"</string></value></member>"+
                    "<member><name>albumid</name><value><string>"+albumid+"</string></value></member>"+
                    "</struct></value></param></params></methodCall>";
            req.open("POST", url);
            req.send(data);

            reqInProgress = true;
        }
    } else {
        console.log("joomeoGetNumberOfFiles: Simultaneous Request. Rejected!");
    }
}

function dismissRequest()
{
    reqInProgress = false;
    if(req)
        req.abort();
}

