// This is the login page.
// This page has basically 5 fields (spacename, loginname, password, a button to choose
//  whether to save previous information into non volatile memory and a connect button)
// Saving information is performed by Settings, an instance of a C++ class (settings.h) visible as a QML
// object. The C++ instance is created in main.cpp and the mapping as a QML object is also performed
// in main.cpp
// When the connect button is pushed, a new page is created (AlbumsPage). The data in the fields are
// transmitted as parameters to AlbumsPage. AlbumsPage will manage connection to Internet.
// To improve:
// - use states to manage change of orientation
// - avoid to hardcode screen resolution
// - take into account heigth of status line for screen size

import QtQuick 1.1
import com.nokia.meego 1.0
import "Constants.js" as Constants
import "UIConstants.js" as UIConstants


Page {

    orientationLock: PageOrientation.LockPortrait

    // Login page is a column with labels, edit fields, button and separator

    Column {
        spacing: 2
        width: (screen.currentOrientation == Screen.Portrait) ? 480 : 854

        Rectangle {
            color: "black"
            width: parent.width
            height: 10
        }

        Row {
            spacing: 10
            width: parent.width

            Image {
                height: UIConstants.INAPP_ICON_SIZE
                width: UIConstants.INAPP_ICON_SIZE
                source: "qrc:///icons/joomeo.png"
                smooth: true
                fillMode: Image.PreserveAspectFit
            }

            Label {
                anchors {
                    verticalCenter: parent.verticalCenter
                }
                // Use qsTr string for strings to localize
                text: qsTr("Joomeo")
                font.pixelSize: 36
            }
        }

        Rectangle {
            color: "black"
            width: parent.width
            height: 10
        }

        Label {
            text: qsTr("View Joomeo Albums")
            color: "white"
        }
        Label {
            text: qsTr("with this application")
            color: "white"
        }
        Rectangle {
            color: "black"
            width: parent.width
            height: 10
        }
        Rectangle {
            color: "gray"
            width: parent.width
            height: 1
        }
        Rectangle {
            color: "black"
            width: parent.width
            height: 10
        }
        Label {
            text: qsTr("Spacename")
            color: "gray"
        }

        TextField {
            id: inputSpace
            text: settings.value("userspace", "");
            width: parent.width

            Keys.onReturnPressed: {
                platformCloseSoftwareInputPanel()
                inputLogin.focus = true
            }
        }
        Rectangle {
            color: "black"
            width: parent.width
            height: 10
        }
        Label {
            text: qsTr("Username (e-mail for owner)")
            color: "gray"
        }

        TextField {
            id: inputLogin
            text: settings.value("username", "");
            width: parent.width
            Keys.onReturnPressed: {
                platformCloseSoftwareInputPanel()
                inputPassword.focus = true
            }
        }
        Rectangle {
            color: "black"
            width: parent.width
            height: 10
        }
        Label {
            text: qsTr("Password")
            color: "gray"
        }
        TextField {
            id: inputPassword
            text: settings.value("password", "");
            echoMode: TextInput.Password
            width: parent.width
            Keys.onReturnPressed: {
                platformCloseSoftwareInputPanel()
                idSaveSettings.focus = true
            }
        }
        Rectangle {
            color: "black"
            width: parent.width
            height: 10
        }
        CheckBox {
            id: idSaveSettings
            checked: settings.value("saveparams", true);
            text: qsTr("Save these data")
            onClicked: {
                settings.setValue("saveparams", checked ? "true" : "false");
                settings.setValue("userspace", checked ? inputSpace.text : "");
                settings.setValue("username", checked ? inputLogin.text : "");
                settings.setValue("password", checked ? inputPassword.text : "");
            }
        }
        Rectangle {
            height: 80
            width: parent.width
            color: "black"
            Button{
                id: idConnect
                anchors.centerIn: parent
                text: qsTr("Connect")
                onClicked: {
                    settings.setValue("saveparams", idSaveSettings.checked ? "true" : "false");
                    settings.setValue("userspace", idSaveSettings.checked ? inputSpace.text : "");
                    settings.setValue("username", idSaveSettings.checked ? inputLogin.text : "");
                    settings.setValue("password", idSaveSettings.checked ? inputPassword.text : "");

                    appWindow.pageStack.push(Qt.resolvedUrl("AlbumsPage.qml"),
                                             { spacename: inputSpace.text,
                                               username: inputLogin.text,
                                               password: inputPassword.text});
                }
            }
        }
        Rectangle {
            color: "black"
            width: parent.width
            height: 100

            Text {
                anchors.horizontalCenter: parent.horizontalCenter
                anchors.bottom: parent.bottom
                font.pixelSize: UIConstants.DEFAULT_FONT_SIZE_LARGE
                color: "steelblue"
                text: qsTr("<a href=\"http://www.joomeo.com/fr/privacypolicy.php\">Privacy Policy</a>")
                onLinkActivated: Qt.openUrlExternally(link)
             }
        }
        Rectangle {
            color: "black"
            width: parent.width
            height: 100

            Label {
                anchors.horizontalCenter: parent.horizontalCenter
                anchors.bottom: parent.bottom
                text: qsTr("version")+" "+appVersion+" - RLH"
                color: "gray"
            }
        }
    }
}

