// Manage display of a photo in zoom mode
// The parent item (a grid object) is defined in FilesPage

import QtQuick 1.1
import com.nokia.meego 1.0
import "Constants.js" as Constants
import "UIConstants.js" as UIConstants

Item {
    id: idPhotoDelegate

    signal clicked
    property string fileId
    property string fileName
    property string dateShooting
    property string fileLegend
    property bool showDetails
    property alias imageStatus : idPhotoImage.status

    width: (screen.currentOrientation == Screen.Portrait) ? 480 : 854
    height:  (screen.currentOrientation == Screen.Portrait) ? 838 : 464

    Image {
        id: idPhotoImage
        source: "http://api.joomeo.com/file.php?apikey="+Constants.API_KEY+"&sessionid="+sessionId+"&albumid="+albumId+"&fileid="+fileId+"&type=large&rotation=0"
        fillMode: Image.PreserveAspectFit
        smooth: true
        width: (screen.currentOrientation == Screen.Portrait) ? 480 : 854
        height:  (screen.currentOrientation == Screen.Portrait) ? 838 : 464
        anchors.centerIn: parent
        cache: false

        onStatusChanged:{
            if (status == Image.Ready) {
                idBusyIndicator.running = false
                idBusyIndicator.visible = false
            }
        }
    }

    // This is the details window (at the top of the screen)
    // This window overlays the photo (opacity)

    Rectangle {
        id: idPhotoDetails
        visible: showDetails
        anchors.fill: idPhotoDetailsColumn
        opacity: 0.7
        color: "black"
    }

    Column {
        id: idPhotoDetailsColumn
        visible: showDetails
        spacing: 2
        Text {
            text: fileLegend
            font.pixelSize: 22
            font.bold: true
            color: "white"
            maximumLineCount: 3
            wrapMode: Text.Wrap
            width: (screen.currentOrientation == Screen.Portrait) ? 480 : 854
        }
        Text {
            font.pixelSize: 18
            color: "white"
            text: Qt.formatDateTime(new Date(parseFloat(idLargePhoto.dateShooting)), "dd MMM yyyy hh:mm:ss")
        }
    }


    MouseArea {
        anchors.fill: parent
        onClicked: idPhotoDelegate.clicked();
    }

    // Rounded Rectangle shown while photo is loading
    BusyIndicator {
        id: idBusyIndicator
        anchors.centerIn: parent
        running: true
        platformStyle: BusyIndicatorStyle {
            size: "large"
        }
    }
}
